<h1 align="center">Colored Python</h1>
<p>
  <img alt="Version" src="https://img.shields.io/badge/version-Your version.-blue.svg?cacheSeconds=2592000" />
  <a href="https://github.com/just-a-mango/opensource-template/blob/main/LICENSE" target="_blank">
    <img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-yellow.svg" />
  </a>
</p>

<p align="center"><b><i>A lightweight python module to print colored text to the terminal easily </b></i></p>

## Description
A more detailed description of your project.

## 📝 License

Copyright © 2022 [Just_a_mango](https://github.com/just-a-mango).<br />
This project is [MIT](https://github.com/just-a-mango/coloredpython/blob/main/LICENSE) licensed.
